@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2019-06-24'; # DATE
-our $VERSION = '0.094'; # VERSION
+our $DATE = '2019-07-16'; # DATE
+our $VERSION = '0.095'; # VERSION
 
 use 5.010001;
 use strict;
@@ -208,6 +208,11 @@ _
             'x.doc.show_result' => 0,
         },
     ],
+    links => [
+        {url=>'prog:durseq', summary=>'Produce sequence of date durations'},
+        {url=>'prog:seq'},
+        {url=>'prog:seq-pl', summary=>'Perl variant of seq'},
+    ],
 };
 sub dateseq {
     require DateTime::Duration;
@@ -332,7 +337,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.094 of App::dateseq (from Perl distribution App-dateseq), released on 2019-06-24.
+This document describes version 0.095 of App::dateseq (from Perl distribution App-dateseq), released on 2019-07-16.
 
 =head1 FUNCTIONS
 
@@ -436,6 +441,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+
+L<durseq>. Produce sequence of date durations.
+
+L<seq>.
+
+L<seq-pl>. Perl variant of seq.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
